tpDcc-tools-datalibrary
============================================================

Tool to manage DCC related data in an easy way.

.. image:: https://travis-ci.com/tpDcc/tpDcc-tools-datalibrary.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/tpDcc/tpDcc-tools-datalibrary

.. image:: https://coveralls.io/repos/github/tpDcc/tpDcc-tools-datalibrary/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/tpDcc/tpDcc-tools-datalibrary?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://tpDcc.github.io/tpDcc-tools-datalibrary

.. image:: https://img.shields.io/github/license/tpDcc/tpDcc-tools-datalibrary
    :target: https://github.com/tpDcc/tpDcc-tools-datalibrary/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/tpDcc-tools-datalibrary?branch=master&kill_cache=1
    :target: https://pypi.org/project/tpDcc-tools-datalibrary

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/